@@ -1,11 +1,12 @@
 package Geometry::Primitive::Polygon;
 use Moose;
-
 use MooseX::AttributeHelpers;
+use MooseX::Storage;
 
 extends 'Geometry::Primitive';
 
 with qw(Geometry::Primitive::Shape MooseX::Clone);
+with Storage(format => 'JSON', io => 'File');
 
 has 'points' => (
     metaclass => 'Collection::Array',
@@ -68,7 +69,7 @@ __END__
 
 =head1 NAME
 
-Geometry::Primitive::Polygon
+Geometry::Primitive::Polygon - Closed shape with an arbitrary number of points.
 
 =head1 DESCRIPTION
 
@@ -79,7 +80,7 @@ series of points that represent a closed path.
 
   use Geometry::Primitive::Polygon;
 
-  my $poly = Geometry::Primitive::Polygon->new();
+  my $poly = Geometry::Primitive::Polygon->new;
   $poly->add_point($point1);
   $poly->add_point($point2);
   $poly->add_point($point3);
@@ -129,6 +130,10 @@ Get the end point.  Provided for Shape role.
 
 Get the start point.  Provided for Shape role.
 
+=item I<points>
+
+Set/Get the arrayref of points that make up this Polygon.
+
 =item I<scale ($amount)>
 
 Scale this this polygon by the supplied amount.
